# Visa Checkout

## iOS Hybrid Mobile App Integration

### Copyright

#### Important Note on Intellectual Property

This document is protected by copyright restricting its use, copying, distribution, and decompilation and is furnished by Visa Inc. for review and informational purposes only or as otherwise specified under and in strict accordance with the applicable agreement between the reader of this document (“You”) and Visa Inc. (“Agreement”). Any other use of this document is strictly prohibited and, except as permitted by the Agreement, You may not reproduce any part of this document, store this document in a retrieval system, or transmit this document, in any form or by any means, electronic, mechanical, recording, or otherwise, without the prior written consent of Visa Inc. Visa and other trademarks are registered trademarks of Visa International Service Association, and are used under license by Visa Inc. All other product names mentioned herein are the trademarks of their respective owners.

THIS PUBLICATION COULD INCLUDE TECHNICAL INACCURACIES OR TYPOGRAPHICAL ERRORS. CHANGES ARE PERIODICALLY ADDED TO THE INFORMATION HEREIN: THESE CHANGES WILL BE

INCORPORATED IN NEW EDITIONS OF THE PUBLICATION. VISA MAY MAKE IMPROVEMENTS AND/OR

CHANGES IN THE PRODUCT(S) AND/OR THE PROGRAM(S) DESCRIBED IN THIS PUBLICATION AT ANY TIME. NOTHING CONTAINED IN THIS DOCUMENT SHOULD BE INTERPRETED IN ANY WAY AS A GUARANTEE OR WARRANTY OF ANY KIND BY VISA INC.

If you have technical questions or questions regarding a Visa service or capability, contact your Visa representative.

### What's New in Version 5.6.1

- `UIWebView` integration is now supported
- Support for iPhone X (**Face ID** and layout changes)

### About Hybrid Mobile App Integration

#### About the Hybrid Mobile App Plugin

Visa Checkout provides a plugin that enables biometric authentication for your hybrid mobile app. With the plugin, consumers can use Visa Checkout with minimal friction during checkout.
The Visa Checkout plugin provides consumers a streamlined, two-touch secure checkout experience, when you integrate the plugin with your hybrid mobile app. When **Enable Touch ID** and **Remember me** are checked, an existing consumer can use **Touch ID** to log into Visa Checkout:

![](images/Touch_ID_Flow.png)

A new consumer can check **Enable Touch ID** and **Remember me** when enrolling in Visa Checkout. The consumer can choose to cancel **Touch ID** and enter a password at any time. A consumer also can uncheck **Enable Touch ID** to disable it without disabling **Remember me**; however, both must be checked to enable **Touch ID**.

#### Technical Notes About the iOS Hybrid App Plugin

The plugin presents the Visa Checkout lightbox as a native view controller. When the consumer taps the Visa Checkout button, your app invokes the plugin.

- The plugin invokes the JavaScript SDK, which integrates with your website. Your existing JavaScript integration with Visa Checkout does not require modification.
- The hybrid integration consists of including the plugin in your app and initializing it with message handlers, which requires minimal coding.
- The size of the plugin is less than 200KB.

### Quick Start

#### Integrating With an iOS Hybrid Mobile App

To integrate with an iOS hybrid mobile app, you must first add `VisaCheckoutHybrid.framework` to your project. Then add the Visa Checkout message handlers to your web view that displays the **Visa Checkout** button.

##### Prerequisites

You must already have created a hybrid mobile app.

##### Procedure

1. Drag the VisaCheckoutHybrid.framework into the Embedded Binaries section of your Xcode project, ensuring that **Copy items if needed** is checked:

 ![](images/Copy_Items.png)

2. Make sure to `import VisaCheckoutHybrid` in all files that use it.

3. Add the following lines to the `viewDidLoad` method of the `UIViewController` that includes the **Visa Checkout** button, depending on whether your app uses a `WKWebView` or a `UIWebView` object:

    **WKWebView**

        VisaCheckoutPlugin.configure(webView.configuration.userContentController, viewController: self)

    **UIWebView**

        VisaCheckoutPlugin.configure(with: webView, viewController: self)

4.  (**This step is for `UIWebView` only**) If your app uses a `UIWebView`, in the `webView:shouldStartLoadWith:navigationType` `UIWebViewDelegate` method, add the following code at the top of the method:

        if VisaCheckoutPlugin.shouldHandle(request) {
            VisaCheckoutPlugin.handle(request)
            return false
        }

5. Remove the simulator architectures from the binary framework before uploading the app to the App Store.

 More discussion on the topic can be found at http://stackoverflow.com/questions/30547283/submit-to-app-store-issues/30866648. The SDK includes a script to perform removal if you do not already have one as part of your project. If you use the removeSimulatorArchitecturesBuildPhase.sh script in the SDK

 a. Create a new **Run Script** in your **Build Phases** tab by clicking the **+** in the top left corner. Ensure that you drag the Run Script below the **Embedded Frameworks** phase.

 b. Type the path to `removeSimulatorArchitecturesBuildPhase.sh` in the script window. If this file is in the same directory as your `xcodeproj` file, you can enter `$PROJECT_DIR/removeSimulatorArchitecturesBuildPhase.sh` into the script window.

 c. Ensure the `Run script only when installing` option is checked.

 ![](images/Remove_Archs.png)

6. In **iOS 11**, applications that use **Face ID** are required to have an entry for the [NSFaceIDUsageDescription](https://developer.apple.com/library/content/documentation/General/Reference/InfoPlistKeyReference/Articles/CocoaKeys.html#//apple_ref/doc/uid/TP40009251-SW75) (`Privacy - Face ID Usage Description`) key in their `Info.plist` file. This `String` lets you describe the reason your app uses **Face ID** and is displayed to users upon a **Face ID** authentication prompt. It is highly recommended to include this key in your app's `Info.plist` since a main feature of the **Visa Checkout** Plugin is easier authentication. This key is required in the main bundle's `Info.plist` and could have a value of any `String`. The simplest solution is using an empty string `""`, since the subtext isn't really necessary and then you don't have to worry about localizing the `String`.

##### Results

After completing these steps, your Xcode project looks similar to one of the following:

- **WKWebView**

 ![](images/Results_WK.png)

- **UIWebView**

 ![](images/Results_UI.png)
