/**
 Copyright © 2017 Visa. All rights reserved.
 */

import UIKit
import WebKit

class ViewController: UIViewController {
    @IBOutlet var container: UIStackView!
    
    lazy var webView: WKWebView = {
        let webView = WKWebView()
        if let url = URL(string: "https://demo.visacheckout.com/presidio") {
            let request = URLRequest(url: url)
            webView.load(request)
        }
        self.container.addArrangedSubview(webView)
        return webView
    }()

    override func viewDidLoad() {
        super.viewDidLoad()
        
        setupVisaCheckout()
    }
}


// MARK: Visa Checkout Integration
import VisaCheckoutHybrid
fileprivate extension ViewController {
    
    /**
     Initialize the Visa Checkout Plugin by setting up the required 
     message handlers and presenting view controller
     
     As a convenience, this entire code setup can be done for you by
     calling the following:
     
     ````
     VisaCheckoutPlugin.configure(webView.configuration.userContentController, viewController: self)
     ````
     */
    fileprivate func setupVisaCheckout() {
        let controller = webView.configuration.userContentController
        controller.add(VisaCheckoutPlugin.main, name: VisaMessageHandler.configureVisaCheckoutPlugin)
        controller.add(VisaCheckoutPlugin.main, name: VisaMessageHandler.launchVisaCheckout)
        VisaCheckoutPlugin.main.presentingViewController = self
    }
}
